﻿<?xml version="1.0" encoding="utf-8"?>
<xsl:stylesheet version="2.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
    xmlns:msxsl="urn:schemas-microsoft-com:xslt"
		xmlns="http://www.w3.org/1999/xhtml"
		exclude-result-prefixes="msxsl">

	<xsl:output method="html" indent="yes"/>

	<xsl:variable name="editionString">Standard</xsl:variable>

	<xsl:template match="/Readme">
		<!-- Matches root element. Handles HTML "plumbing" (header, footer, etc.) -->

		<!-- <!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"> -->
		<html xmlns="http://www.w3.org/1999/xhtml">
			<head>
				<meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
				<meta name="author" content="Autodesk, Inc." />
				<title>Autodesk® Factory Design Suite</title>
				<link href="css/style.css" rel="stylesheet" type="text/css" />
				<div class="header">
					<div class="title">
						<img src="images/FDS_{$editionString}.png" width="700" height="70" alt="Autodesk® Factory Design Suite {$editionString} 2012" />
					</div>
					<div class="logo">
						<img src="images/autodesk-logo.gif" width="84" height="14" alt="Autodesk" />
					</div>
				</div>
			</head>
			<body>
				<div class="wrapper">
					<div class="main">

				<!-- Handle other data in separate templates -->
				<xsl:apply-templates/>

					</div>
					<!-- main -->
				</div>
				<!-- wrapper -->

				<div class="footer">© Copyright 2011 Autodesk, Inc.</div>

			</body>
		</html>

	</xsl:template>

	<xsl:template match="Intro">
		<a name="Top"></a>
		<xsl:apply-templates />

		<xsl:call-template name="TableOfContents"/>
		
	</xsl:template>

	<xsl:template name="TableOfContents">
		<h3>Contents</h3>
		<ul>
			<li><a href="#Suite_Components">Suite Components</a></li>
			<li><a href="#Supported_Operating_Systems">Supported Operating Systems</a></li>
			<li><a href="#Installation_Instructions">Installation Instructions</a></li>
			<li><a href="#Known_Issues">Known Issues</a></li>
		</ul>
		<br/>
	</xsl:template>

	<xsl:template match="Components">
		<h3><a name="Suite_Components"></a>Suite Components</h3>
		<p>&#0160;</p>
		<p>Autodesk Factory Design Suite <xsl:value-of select="$editionString"/> 2012 includes the following components:</p><br/>
		<ul>
			<xsl:apply-templates/>
		</ul>
		<xsl:call-template name="AddReturnToTop"/>
	</xsl:template>

	<xsl:template match="Component">
		<!-- Check Editions attribute -->
		<xsl:variable name="editionCheck"><xsl:call-template name="CheckEdition"/></xsl:variable>
		<xsl:if test="$editionCheck='true'">
			<li><xsl:apply-templates/></li>
		</xsl:if>
	</xsl:template>

	<!-- Returns a true/false indication (as a string) of whether the current editionString
	     matches the specified Editions attribute. A missing attribute results in a 'true' result. -->
	<xsl:template name="CheckEdition">
		
		<xsl:variable name="isSupported">
			<xsl:choose>
				<xsl:when test="string(@Editions) = ''">
					<xsl:value-of select="true()"/>
				</xsl:when>
				<xsl:otherwise>
					<!-- Check for contents -->
					<xsl:value-of select="contains(@Editions, $editionString)"/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>

		<xsl:value-of select="$isSupported"/>
		
	</xsl:template>

	<xsl:template match="SystemRequirements">
		<h3><a name="Supported_Operating_Systems"></a>Supported Operating Systems</h3>
		<p>&#0160;</p>
		<p>You can use this installation with the following operating systems:</p>

		<xsl:apply-templates/>

		<xsl:call-template name="AddReturnToTop"/>
	</xsl:template>

	<xsl:template match="SupportedOS">

		<p>&#0160;</p>
		<p><xsl:value-of select="@Name"/></p>
		<ul>
			<xsl:apply-templates/>
		</ul>

	</xsl:template>

	<xsl:template match="OSEdition">

		<li><xsl:apply-templates/></li>
		
	</xsl:template>
	
	<xsl:template match="InstallationNotes">
		<h3><a name="Installation_Instructions"></a>Installation Instructions</h3>
		<p>&#0160;</p>

		<xsl:apply-templates />

		<xsl:call-template name="AddReturnToTop"/>
	</xsl:template>

	<xsl:template match="KnownIssues">
		<h3><a name="Known_Issues"></a>Known Issues</h3>
		<p>&#0160;</p>

		<xsl:apply-templates />

		<xsl:call-template name="AddReturnToTop"/>
	</xsl:template>

	<xsl:template match="IssueCategory">

		<!-- Check for matching edition -->
		<xsl:variable name="editionCheck"><xsl:call-template name="CheckEdition"/></xsl:variable>
		<xsl:if test="$editionCheck='true'">
			<h4><xsl:value-of select="@Name"/></h4>
			<ul>
				<xsl:apply-templates/>
			</ul>
			<p>&#0160;</p>
		</xsl:if>

	</xsl:template>

	<xsl:template match="Issue">

		<li><xsl:apply-templates/></li>
		
	</xsl:template>

	<xsl:template name="AddReturnToTop">
		<p align="right"><a href="#Top">Return to Top </a></p>
	</xsl:template>
	
	<xsl:template match="ProductFullName">Autodesk® Factory Design Suite <xsl:value-of select="$editionString"/> 2012</xsl:template>
	<xsl:template match="ProductShortName">Factory Design Suite <xsl:value-of select="$editionString"/> 2012</xsl:template>

	<xsl:template match="Para">
		<p><xsl:apply-templates /></p>
		<p>&#0160;</p>
	</xsl:template>

	<xsl:template match="Emphasis">
		<strong><xsl:apply-templates/></strong>
	</xsl:template>
	
</xsl:stylesheet>
